import { IWindowSize } from './type';
/**
 * A React hook designed for monitoring and retrieving the dimensions of the browser's window.
 * This hook facilitates responsive design by providing real-time updates on window resizing events.
 * It ensures that components can react to changes in window size, making it particularly useful
 * for adaptive and responsive layouts.
 *
 * The hook leverages a throttling mechanism to optimize performance during continuous resize events,
 * minimizing potential performance impacts on the application.
 *
 * Usage:
 * const { width, height } = useCurrentWindowSize();
 *
 * @return {IWindowSize} An object containing the current `width` and `height` of the window.
 */
export declare const useCurrentWindowSize: () => IWindowSize;
